Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / invariant / __init__.py | (no class) |  | 8 | 0 | 0 |  | 100.00%
src / invariant / cacheable.py | (no class) |  | 33 | 1 | 0 |  | 96.97%
src / invariant / executor.py | Executor |  | 56 | 6 | 0 |  | 89.29%
src / invariant / executor.py | (no class) |  | 12 | 0 | 3 |  | 100.00%
src / invariant / expressions.py | (no class) |  | 171 | 11 | 0 |  | 93.57%
src / invariant / graph.py | GraphResolver |  | 65 | 1 | 0 |  | 98.46%
src / invariant / graph.py | (no class) |  | 11 | 0 | 2 |  | 100.00%
src / invariant / graph_serialization.py | (no class) |  | 215 | 33 | 0 |  | 84.65%
src / invariant / hashing.py | (no class) |  | 42 | 0 | 0 |  | 100.00%
src / invariant / node.py | Node |  | 12 | 1 | 0 |  | 91.67%
src / invariant / node.py | SubGraphNode |  | 14 | 0 | 0 |  | 100.00%
src / invariant / node.py | (no class) |  | 31 | 0 | 0 |  | 100.00%
src / invariant / ops / __init__.py | (no class) |  | 3 | 0 | 0 |  | 100.00%
src / invariant / ops / poly.py | (no class) |  | 40 | 4 | 0 |  | 90.00%
src / invariant / ops / stdlib.py | (no class) |  | 18 | 0 | 0 |  | 100.00%
src / invariant / params.py | ref |  | 0 | 0 | 0 |  | 100.00%
src / invariant / params.py | cel |  | 0 | 0 | 0 |  | 100.00%
src / invariant / params.py | (no class) |  | 7 | 0 | 0 |  | 100.00%
src / invariant / protocol.py | ICacheable |  | 3 | 3 | 0 |  | 0.00%
src / invariant / protocol.py | IJsonRepresentable |  | 2 | 2 | 0 |  | 0.00%
src / invariant / protocol.py | (no class) |  | 16 | 2 | 0 |  | 87.50%
src / invariant / registry.py | OpRegistry |  | 49 | 9 | 0 |  | 81.63%
src / invariant / registry.py | (no class) |  | 15 | 0 | 0 |  | 100.00%
src / invariant / store / __init__.py | (no class) |  | 6 | 0 | 0 |  | 100.00%
src / invariant / store / base.py | CacheStats |  | 0 | 0 | 0 |  | 100.00%
src / invariant / store / base.py | ArtifactStore |  | 5 | 3 | 0 |  | 40.00%
src / invariant / store / base.py | (no class) |  | 17 | 0 | 0 |  | 100.00%
src / invariant / store / chain.py | ChainStore |  | 21 | 0 | 0 |  | 100.00%
src / invariant / store / chain.py | (no class) |  | 9 | 0 | 0 |  | 100.00%
src / invariant / store / codec.py | (no class) |  | 155 | 0 | 0 |  | 100.00%
src / invariant / store / disk.py | DiskStore |  | 35 | 2 | 0 |  | 94.29%
src / invariant / store / disk.py | (no class) |  | 12 | 0 | 0 |  | 100.00%
src / invariant / store / memory.py | MemoryStore |  | 36 | 2 | 0 |  | 94.44%
src / invariant / store / memory.py | (no class) |  | 18 | 0 | 0 |  | 100.00%
src / invariant / store / null.py | NullStore |  | 3 | 0 | 0 |  | 100.00%
src / invariant / store / null.py | (no class) |  | 6 | 0 | 0 |  | 100.00%
src / invariant / types.py | Polynomial |  | 24 | 1 | 2 |  | 95.83%
src / invariant / types.py | (no class) |  | 13 | 0 | 1 |  | 100.00%
Total |  |  | 1183 | 81 | 8 |  | 93.15%

No items found using the specified filter.